package com.huiju.estateagents.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.huiju.estateagents.entity.TaBuildingApartment;
import com.huiju.estateagents.entity.TaHousingResources;
import com.huiju.estateagents.po.TaHousingResourcesPO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * <p>
 * 房源表  Mapper 接口
 * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@Mapper
@Component
public interface TaHousingResourcesMapper extends BaseMapper<TaHousingResources> {

    /**
     * 分页获取房源列表
     *
     * @param iPage
     * @param salesBatchId
     * @param startPrice
     * @param endPrice
     * @param apartmentId
     * @return
     */
    IPage<TaHousingResourcesPO> listHousingResources(IPage<TaHousingResourcesPO> iPage,
                                                     @Param("salesBatchId") String salesBatchId,
                                                     @Param("startPrice") String startPrice,
                                                     @Param("endPrice") String endPrice,
                                                     @Param("apartmentId") String apartmentId);

    /**
     * 获取某销售批次下所有房源户型
     *
     * @param salesBatchId
     * @return
     */
    List<TaBuildingApartment> listBuildApartmentBySalesBatchId(@Param("salesBatchId") String salesBatchId);

    /**
     * 增加热度值
     *
     * @param houseId
     * @return
     */
    Boolean updateForAddHeat(@Param("houseId") String houseId);

    /**
     * 减少热度值
     *
     * @param houseId
     * @return
     */
    Boolean updateForSubtractHeat(@Param("houseId") String houseId);

    /**
     * 根据房源ID获取房源详情
     *
     * @param houseId
     * @param type    是否只查询已发布数据，1是 0否
     * @return
     */
    TaHousingResourcesPO getHousingDetailById(@Param("houseId") String houseId,
                                              @Param("type") String type);
}
