package com.huiju.estateagents.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaBuildingApartment;
import com.huiju.estateagents.entity.TaBuildingBlock;
import com.huiju.estateagents.entity.TaHousingResources;
import com.huiju.estateagents.mapper.TaHousingResourcesMapper;
import com.huiju.estateagents.po.TaHousingResourcesPO;
import com.huiju.estateagents.service.ITaHousingResourcesService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 房源表  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@Service
public class TaHousingResourcesServiceImpl extends ServiceImpl<TaHousingResourcesMapper, TaHousingResources> implements ITaHousingResourcesService {

    private Logger logger = LoggerFactory.getLogger(TaHousingResourcesServiceImpl.class);

    @Autowired
    private TaHousingResourcesMapper taHousingResourcesMapper;

    /**
     * 分页获取房源详情数据
     *
     * @param salesBatchId
     * @param buildingId
     * @param pageNumber
     * @param pageSize
     * @param orgId
     * @return
     */
    @Override
    public ResponseBean selectPageList(Integer salesBatchId, String buildingId, Integer pageNumber, Integer pageSize, Integer orgId) {
        //使用分页插件
        IPage<TaHousingResources> pg = new Page<>(pageNumber, pageSize);
        QueryWrapper<TaHousingResources> queryWrapper = new QueryWrapper<>();
        //销售批次id
        queryWrapper.eq("sales_batch_id", salesBatchId);
        queryWrapper.eq("building_id", buildingId);
        queryWrapper.eq("org_id", orgId);
        queryWrapper.eq("status", CommConstant.STATUS_NORMAL);
        queryWrapper.orderByDesc("create_date");
        IPage<TaHousingResources> list = this.page(pg, queryWrapper);

        return ResponseBean.success(list);
    }

    /**
     * 分页获取房源列表
     *
     * @param pageNum      页码
     * @param pageSize     分页大小
     * @param salesBatchId 销售批次ID
     * @param startPrice
     * @param endPrice
     * @param apartmentId
     * @return
     */
    @Override
    public IPage<TaHousingResourcesPO> listHousingResources(Integer pageNum, Integer pageSize, String salesBatchId, String startPrice, String endPrice, String apartmentId) {
        logger.info("listHousingResources 接收参数：pageNum：{},pageSize：{},salesBatchId：{},startPrice：{},endPrice：{},apartmentId：{}",
                pageNum, pageSize, salesBatchId, startPrice, endPrice, apartmentId);

        IPage<TaHousingResourcesPO> iPage = new Page<>(pageNum, pageSize);
        return taHousingResourcesMapper.listHousingResources(iPage, salesBatchId, startPrice, endPrice, apartmentId);
    }

    /**
     * 获取某销售批次下所有房源户型
     *
     * @param salesBatchId
     * @return
     */
    @Override
    public List<TaBuildingApartment> listBuildApartmentBySalesBatchId(String salesBatchId) {
        logger.info("listBuildApartmentBySalesBatchId 接收参数：salesBatchId：{}", salesBatchId);

        return taHousingResourcesMapper.listBuildApartmentBySalesBatchId(salesBatchId);
    }

    /**
     * 根据房源ID获取房源详情
     *
     * @param personId
     * @param houseId
     * @return
     */
    @Override
    public TaHousingResourcesPO getHousingDetailById(String personId, String houseId) {
        logger.info("getHousingDetailById 接收参数：personId：{}，houseId：{}", personId, houseId);

        return taHousingResourcesMapper.getHousingDetailById(houseId, "1");
    }
}
