package com.huiju.estateagents.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.DateUtils;
import com.huiju.estateagents.entity.TaPreselectionRecord;
import com.huiju.estateagents.mapper.TaHousingResourcesMapper;
import com.huiju.estateagents.mapper.TaPreselectionRecordMapper;
import com.huiju.estateagents.po.TaHousingResourcesPO;
import com.huiju.estateagents.po.TaPreselectionRecordPO;
import com.huiju.estateagents.service.ITaPreselectionRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * <p>
 * 预选记录表  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@Service
public class TaPreselectionRecordServiceImpl extends ServiceImpl<TaPreselectionRecordMapper, TaPreselectionRecord> implements ITaPreselectionRecordService {

    private Logger logger = LoggerFactory.getLogger(TaPreselectionRecordServiceImpl.class);

    @Autowired
    private TaPreselectionRecordMapper taPreselectionRecordMapper;

    @Autowired
    private TaHousingResourcesMapper taHousingResourcesMapper;

    @Override
    public IPage<TaPreselectionRecordPO> listPreselectionRecord(Integer pageNum, Integer pageSize, String personId) {
        logger.info("listPreselectionRecord 接收参数：pageNum：{}，pageSize：{}，personId：{}", pageNum, pageSize, personId);

        IPage<TaPreselectionRecordPO> iPage = new Page<>(pageNum, pageSize);
        return taPreselectionRecordMapper.listPreselectionRecord(iPage, personId);
    }

    @Override
    @Transactional
    public ResponseBean taPreselectionRecordAdd(TaPreselectionRecord taPreselectionRecord) {
        logger.info("listPreselectionRecord 接收参数：taPreselectionRecord:{}", JSONObject.toJSONString(taPreselectionRecord));

        ResponseBean responseBean = new ResponseBean();

        // 校验用户是否已经预选房源
        TaPreselectionRecord record = taPreselectionRecordMapper
                .getRecordByPersonIdAndHouseId(taPreselectionRecord.getPersonId(), taPreselectionRecord.getHouseId());
        if (record != null) {
            responseBean.addError("您已经预选过该房源");
            return responseBean;
        }

        TaHousingResourcesPO resourcesPO = taHousingResourcesMapper.getHousingDetailById(taPreselectionRecord.getHouseId(), "0");
        if (resourcesPO == null) {
            responseBean.addError("fail");
            return responseBean;
        }

        // 校验当前批次状态是否为已发布
        if (resourcesPO.getSaleBatchStatus() != 1) {
            responseBean.addError("当前销售批次已临时取消发布，请稍后再试或联系置业顾问了解详情。");
            return responseBean;
        }

        // 校验当前房源状态是否为已发布
        if (!"1".equals(resourcesPO.getStatus())) {
            responseBean.addError("当前房源已临时取消发布，请稍后再试或联系置业顾问了解详情。");
            return responseBean;
        }

        // 校验预选操作时间是否在规定范围内
        if (DateUtils.checkTimeRange(resourcesPO.getPreselectionStartTime(), resourcesPO.getPreselectionEndTime(), null)) {
            responseBean.addError("当前时间不在预选时间范围内，请联系置业顾问了解详情。");
            return responseBean;
        }

        // 添加预选记录
        taPreselectionRecord.setStatus(1);
        taPreselectionRecord.setCreateDate(LocalDateTime.now());
        save(taPreselectionRecord);

        // 更新房源表热度
        Boolean result = taHousingResourcesMapper.updateForAddHeat(taPreselectionRecord.getHouseId());
        if (result) {
            responseBean.addSuccess(taPreselectionRecord);
            return responseBean;
        }
        responseBean.addError("fail");
        return responseBean;
    }

    @Override
    @Transactional
    public Boolean taPreselectionRecordCancel(String personId, String houseId) {
        logger.info("taPreselectionRecordCancel 接收参数：personId：{}，houseId：{}", personId, houseId);

        // 更新预选记录
        TaPreselectionRecord record = new TaPreselectionRecord();
        record.setPreselectionRecordId(Integer.parseInt(personId));
        record.setStatus(0);
        record.setUpdateDate(DateUtils.today());
        updateById(record);

        // 更新房源表热度
        return taHousingResourcesMapper.updateForSubtractHeat(houseId);
    }

    @Override
    public TaPreselectionRecord checkPreselect(String personId, String houseId) {
        logger.info("checkPreselect 接收参数：personId：{}，houseId：{}", personId, houseId);

        return taPreselectionRecordMapper.getRecordByPersonIdAndHouseId(personId, houseId);
    }
}
